==> react-hooks-1.26.0.tgz: package/lib/useCopyToClipboard/index.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import { useCallback } from 'react';
import copy from 'clipboard-copy';
import useMountedState from '../useMountedState';
import useSetState from '../useSetState';
export default function useCopyToClipboard() {
  var isMounted = useMountedState();

  var _useSetState = useSetState({
    value: undefined,
    error: undefined
  }),
      state = _useSetState[0],
      setState = _useSetState[1];

  var copyToClipboard = useCallback( /*#__PURE__*/function () {
    var _ref = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(value) {
      var normalizedValue, error, _error;

      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              if (isMounted()) {
                _context.next = 2;
                break;
              }

              return _context.abrupt("return", null);

            case 2:
              _context.prev = 2;

              if (!(typeof value !== 'string' && typeof value !== 'number')) {
                _context.next = 10;
                break;
              }

              error = new Error("Cannot copy typeof " + typeof value + " to clipboard, must be a string");
              if (process.env.NODE_ENV === 'development') console.error(error); // eslint-disable-line no-console

              setState({
                value: value,
                error: error
              });
              return _context.abrupt("return", null);

            case 10:
              if (!(value === '')) {
                _context.next = 15;
                break;
              }

              _error = new Error("Cannot copy empty string to clipboard.");
              if (process.env.NODE_ENV === 'development') console.error(_error); // eslint-disable-line no-console

              setState({
                value: value,
                error: _error
              });
              return _context.abrupt("return", null);

            case 15:
              normalizedValue = value.toString();
              _context.prev = 16;
              _context.next = 19;
              return copy(normalizedValue);

            case 19:
              setState({
                value: normalizedValue,
                error: undefined
              });
              _context.next = 27;
              break;

            case 22:
              _context.prev = 22;
              _context.t0 = _context["catch"](16);
              if (process.env.NODE_ENV === 'development') console.error(_context.t0); // eslint-disable-line no-console

              setState({
                value: value,
                error: _context.t0
              });
              return _context.abrupt("return", null);

            case 27:
              _context.next = 32;
              break;

            case 29:
              _context.prev = 29;
              _context.t1 = _context["catch"](2);
              setState({
                value: normalizedValue,
                error: _context.t1
              });

            case 32:
            case "end":
              return _context.stop();
          }
        }
      }, _callee, null, [[2, 29], [16, 22]]);
    }));

    return function (_x) {
      return _ref.apply(this, arguments);
    };
  }(), [isMounted, setState]);
  return [state, copyToClipboard];
}

==> react-hooks-1.28.0.tgz: package/lib/useCopyToClipboard/index.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import { useCallback, useState } from 'react';
import { clipboardCopy as copy } from './clipboard-copy';
import useMountedState from '../useMountedState';
export default function useCopyToClipboard() {
  var isMounted = useMountedState();

  var _useState = useState({
    value: undefined,
    error: undefined
  }),
      _useState$ = _useState[0],
      value = _useState$.value,
      error = _useState$.error,
      setState = _useState[1];

  var copyToClipboard = useCallback( /*#__PURE__*/function () {
    var _ref = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(value) {
      var normalizedValue, _error, _error2;

      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              if (isMounted()) {
                _context.next = 2;
                break;
              }

              return _context.abrupt("return", null);

            case 2:
              _context.prev = 2;

              if (!(typeof value !== 'string' && typeof value !== 'number')) {
                _context.next = 9;
                break;
              }

              _error = new Error("Cannot copy typeof " + typeof value + " to clipboard, must be a string");
              if (process.env.NODE_ENV === 'development') console.error(_error); // eslint-disable-line no-console

              setState({
                value: value,
                error: _error
              });
              _context.next = 14;
              break;

            case 9:
              if (!(value === '')) {
                _context.next = 14;
                break;
              }

              _error2 = new Error("Cannot copy empty string to clipboard.");
              if (process.env.NODE_ENV === 'development') console.error(_error2); // eslint-disable-line no-console

              setState({
                value: value,
                error: _error2
              });
              return _context.abrupt("return", null);

            case 14:
              normalizedValue = value.toString();
              _context.prev = 15;
              _context.next = 18;
              return copy(normalizedValue);

            case 18:
              setState({
                value: value,
                error: undefined
              });
              _context.next = 26;
              break;

            case 21:
              _context.prev = 21;
              _context.t0 = _context["catch"](15);
              if (process.env.NODE_ENV === 'development') console.error(_context.t0); // eslint-disable-line no-console

              setState({
                value: value,
                error: _context.t0
              });
              return _context.abrupt("return", null);

            case 26:
              _context.next = 31;
              break;

            case 28:
              _context.prev = 28;
              _context.t1 = _context["catch"](2);
              setState({
                value: normalizedValue,
                error: _context.t1
              });

            case 31:
            case "end":
              return _context.stop();
          }
        }
      }, _callee, null, [[2, 28], [15, 21]]);
    }));

    return function (_x) {
      return _ref.apply(this, arguments);
    };
  }(), [isMounted, setState]);
  return [{
    value: value,
    error: error
  }, copyToClipboard];
}
